@@ -1,6 +1,5 @@
 use ic_agent::{ic_types::Principal, Identity, Signature};
 
-use openssl::sha::Sha256;
 use pkcs11::{
     types::{
         CKA_CLASS, CKA_EC_PARAMS, CKA_EC_POINT, CKA_ID, CKA_KEY_TYPE, CKF_LOGIN_REQUIRED,
@@ -10,6 +9,10 @@ use pkcs11::{
     },
     Ctx,
 };
+use sha2::{
+    digest::{generic_array::GenericArray, OutputSizeUser},
+    Digest, Sha256,
+};
 use simple_asn1::{
     from_der, oid, to_der,
     ASN1Block::{BitString, ObjectIdentifier, OctetString, Sequence},
@@ -23,7 +26,7 @@ type KeyId = [u8];
 type DerPublicKeyVec = Vec<u8>;
 
 /// Type alias for a sha256 result (ie. a u256).
-type Sha256Hash = [u8; 32];
+type Sha256Hash = GenericArray<u8, <Sha256 as OutputSizeUser>::OutputSize>;
 
 // We expect the parameters to be curve secp256r1.  This is the base127 encoded form:
 const EXPECTED_EC_PARAMS: &[u8; 10] = b"\x06\x08\x2a\x86\x48\xce\x3d\x03\x01\x07";
@@ -134,7 +137,7 @@ impl Identity for HardwareIdentity {
         Ok(Principal::self_authenticating(&self.public_key))
     }
     fn sign(&self, msg: &[u8]) -> Result<Signature, String> {
-        let hash = hash_message(msg);
+        let hash = Sha256::digest(msg);
         let signature = self.sign_hash(&hash)?;
 
         Ok(Signature {
@@ -353,12 +356,6 @@ fn str_to_key_id(s: &str) -> Result<KeyIdVec, HardwareIdentityError> {
     Ok(bytes)
 }
 
-fn hash_message(msg: &[u8]) -> Sha256Hash {
-    let mut sha256 = Sha256::new();
-    sha256.update(msg);
-    sha256.finish()
-}
-
 impl HardwareIdentity {
     fn sign_hash(&self, hash: &Sha256Hash) -> Result<Vec<u8>, String> {
         let private_key_handle =
